package bbs;

import java.util.Date;
import java.text.SimpleDateFormat;
import java.text.ParseException;

public class Message {
   private String userID = null;
   private String message = null;
   private String time = null;
   
   /**
    * The constructor for creating a new message
    *
    * @arg userID The sender of the message
    * @arg message The message body
    */
   public Message(String userID, String message) {
   	this.userID = userID;
   	this.message = message;
   	this.time = (new Date()).toString();
   }
   
   /**
    * The constructor for creating a Message from an existing text 
    * representation of a message.
    *
    * @arg messageStr The string representation of the message.
    */
   public Message(String messageStr) {
   	int dateStart = messageStr.indexOf("(")+1;
   	int dateEnd = messageStr.indexOf(")");
   	this.time = messageStr.substring(dateStart, dateEnd);
   	
   	int userIDStart = messageStr.indexOf(")")+1;
   	int userIDEnd = messageStr.indexOf(">");
   	this.userID = messageStr.substring(userIDStart, userIDEnd);
   	
   	int messageStart = messageStr.indexOf(">")+2;
   	this.message = messageStr.substring(messageStart);
   }

   /**
    * This method creates a string representation of this message.  The
    * format used is one that is presentable (viewable by humans).  You
    * might assume this format would be used directly to show the messages
    * to the user in some GUI component.
    */
   public String toString() {
   	return new String("("+time+")"+userID+"> "+message);
   }
}