package bbs.client;

import bbs.*;
import javax.swing.JOptionPane;
import javax.swing.JFrame;
import javax.swing.JTextArea;
import java.io.IOException;

public class BulletinBoardClient implements MessageObserver {
  private JTextArea outputArea = null;
  
  /**
   * This constructor creates a GUI window, and a connection proxy
   * (which represents a connection to the server) to notify us of
   * incoming messages.
   *
   * @arg address The network address of the server
   * @arg port The network port of the server
   */
  public BulletinBoardClient(String address, int port) {
  	// create the GUI
  	outputArea = new JTextArea(25,50);
  	JFrame frame = new JFrame("BulletinBoard:  Connected to "+address);
  	frame.getContentPane().add(outputArea);
  	frame.setSize(600,400);
  	frame.setVisible(true);
  	frame.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);

  	// create a proxy to handle incoming messages and network communication
  	ClientMessageProxy proxy = null;
  	try {
	  	proxy = new ClientMessageProxy(address, port);
	} catch (IOException e) {
		JOptionPane.showMessageDialog(null,"Unable to connect to server: "+address+":"+port);
		e.printStackTrace();
		System.exit(1);
	}
	
	// tell the proxy to notify us when messages are received
  	proxy.addObserver(this);
  	
  	// start the proxy listening for messages, as a separate thread
  	Thread thread = new Thread(proxy);
  	thread.run();  	
  }
  
  /**
   * This method is called when a message is received (by the client
   * message proxy).  The message is inserted into the output area for
   * viewing.
   *
   * @arg message The new message.
   */
  public void messageReceived(Message message) {
  	// show the message
  	outputArea.append(""+message+"\n");
  }

  /**
   * The main method.  This method is used to run the client.  The user
   * can specify address and port, but they are optional.  If they are
   * not specified, the default values (localhost, 16789) are used.
   *
   * @arg args The command line arguments
   */
  public static void main(String[] args) {
  	// use the command-line arguments for the address and port where available
  	String address = "localhost";
  	if (args.length >= 1) {
  		address = args[0];
  	}
  	int port = 8889;
  	if (args.length >= 2) {
  		port = Integer.parseInt(args[1]);
  	}
  	
  	// create a client using this address and port
  	BulletinBoardClient client = new BulletinBoardClient(address, port);
  }
}