package bbs.server;

import bbs.*;
import javax.swing.JPanel;
import javax.swing.JTextField;
import javax.swing.JTextArea;
import javax.swing.JButton;
import javax.swing.JLabel;
import javax.swing.JFrame;
import java.awt.event.ActionListener;
import java.awt.event.ActionEvent;
import java.awt.event.WindowAdapter;
import java.awt.event.WindowEvent;
import java.awt.BorderLayout;

public class BulletinBoardServer implements ActionListener {
  private ObservableMessageList messageStore = null;
  private JTextField messageInputField = null;
  private JTextField usernameInputField = null;
  private JTextArea outputArea = null;
  private ConnectionManager connectionManager = null;
  
  /**
   * This constructor creates a GUI window, as well as a ConnectionManager
   * which listens for connecting clients.  Connecting clients are handled
   * by ServerMessageProxy which represents the client.
   */
  public BulletinBoardServer() {
  	// create the GUI
  	JPanel mainPanel = new JPanel();
  	JPanel usernamePanel = new JPanel();
  	mainPanel.setLayout(new BorderLayout());
  	usernameInputField = new JTextField(25);
  	usernamePanel.add(new JLabel("Username:"));
  	usernamePanel.add(usernameInputField);
  	mainPanel.add(usernamePanel, BorderLayout.NORTH);
  	messageInputField = new JTextField(25);
  	messageInputField.addActionListener(this);
  	JPanel messagePanel = new JPanel();
  	messagePanel.add(new JLabel("Message:"));
  	messagePanel.add(messageInputField);
  	JButton sendMessageButton = new JButton("Send Message");
  	sendMessageButton.addActionListener(this);
  	messagePanel.add(sendMessageButton);
  	mainPanel.add(messagePanel, BorderLayout.SOUTH);
  	outputArea = new JTextArea(15,40);
  	mainPanel.add(outputArea, BorderLayout.CENTER);
	JFrame frame = new JFrame("Bulletin Board Server");
	frame.getContentPane().add(mainPanel);
	frame.setSize(600,400);
	frame.setVisible(true);

  	// create the message store
  	messageStore = new ObservableMessageList();
  	connectionManager = new ConnectionManager();
  	connectionManager.setMessageStore(messageStore);
  	connectionManager.start();

	frame.addWindowListener(new WindowAdapter() {
		public void windowClosing(WindowEvent event) {
			connectionManager.close();
			System.exit(0);
		}
	});
  }
  
  /**
   * This message is the event handler for the GUI window.  When the user
   * hits enter in the message text field, or presses the 'Send Message'
   * button, this method is called.  This method adds the contents of the
   * message text field to a Message object, and sends it to the server
   * message proxy.
   *
   * @arg event The event that has occurred.
   */
  public void actionPerformed(ActionEvent event) {
  	// assembe the data into a Message object
  	Message msg = new Message(usernameInputField.getText(),messageInputField.getText());
  	
  	// display the message in the display window
  	outputArea.append(msg.toString()+"\n");
  	
  	// tell the message store to distribute the message to its
  	// observers
  	messageStore.addMessage(msg);
  }
  
  /**
   * This is the main method.  This method creates an instance of this
   * server.
   */
  public static void main(String[] args) {
  	BulletinBoardServer server = new BulletinBoardServer();
  }
}