package bbs.server;

import bbs.*;
import java.net.ServerSocket;
import java.net.Socket;
import java.io.PrintWriter;
import java.io.IOException;
import java.util.Vector;

public class ConnectionManager extends Thread {
   private static int DEFAULT_PORT = 16789;

   private ServerSocket serverSocket = null;
   private ObservableMessageList serverMessageStore = null;
   private boolean running = true;

   /**
    * This constructor creates a connection manager on the default port.
    */
   public ConnectionManager() {
	try {
		serverSocket = new ServerSocket(DEFAULT_PORT);
	} catch (IOException e) {
		System.err.println("IOEXception while creating server socket");
		System.exit(1);
	}
  }

  /**
   * This is an accessor method for storing the message list
   *
   * @arg store The message store.
   */
  public void setMessageStore(ObservableMessageList store) {
  	serverMessageStore = store;
  }

  /**
   * This method stops this thread from executing by setting a flag
   */
  public void close() {
  	running = false;
  	try {
	  	serverSocket.close();
	} catch (IOException e) {
		e.printStackTrace();
	}
  }

  /**
   * This method is run when the thread starts executing.  The method calls
   * waitForConnections() to do the main loop of the thread.
   *
   * @see #waitForConnections()
   */
  public void run() {
  	waitForConnections();
  }

  /**
   * This method continuously loops listening for connections.  When a
   * connection occurs, a server message proxy is created to represent
   * the client.
   */
  public void waitForConnections() {
  	while(running) {
  	    try {
  	    	// listen for another connection
		Socket socket = serverSocket.accept(); // freezes here
		
		// we have a connection
		// create a server message proxy to handle the connection
		ServerMessageProxy serverMsgProxy = new ServerMessageProxy(socket);
		
		// let the server message proxy observe our message list
		serverMessageStore.addObserver(serverMsgProxy);
		
		// send the previously issued messages to the proxy (and
		// thus indirectly to the client).
		serverMsgProxy.sendCachedMessages(serverMessageStore);
	    } catch (IOException e) {
		System.err.println("IOEXception while opening a read connection");
		System.exit(0);
	    }
	}
	try {
		// close the server socket, since we want to exit
		serverSocket.close();
	} catch (IOException e) {
		e.printStackTrace();
	}
  }   
}