import junit.framework.*;
import org.junit.Before;
import org.junit.After;

public class AccountServiceTest extends TestCase {
	    private AccountService service;

		@Before public void setUp() {
			service = new AccountService();
			Account account = new Account(1);
			account.setBalance(1000f);
			service.addAccount(account);
			Account account2 = new Account(2);
			account2.setBalance(2000f);
			service.addAccount(account2);
			Account account3 = new Account(3);
			account3.setBalance(3000f);
			service.addAccount(account3);
		}

		public void testNoSuchAccount() {
			Account account = service.getAccount(5);
			assertNull(account);
		}

		public void testGetAccount() {
			Account account = service.getAccount(3);
			assertNotNull(account);
			assertEquals(3000f, account.getBalance());
		}

		public void testAddAccount() {
			Account account4 = new Account(4);
			account4.setBalance(4000f);
			service.addAccount(account4);
			assertEquals(4000f, service.getAccount(4).getBalance());
		}

		public void testDeposit() throws NoSuchAccountException {
			service.deposit(1, 100f);
			Account account = service.getAccount(1);
			assertEquals(1100f, account.getBalance());
		}

		public void testWithdraw() throws NoSuchAccountException, InsufficientFundsException {
			service.withdraw(2, 200f);
			Account account = service.getAccount(2);
			assertEquals(1800f, account.getBalance());
		}

		@After public void tearDown() {
			service = null;
		}
}
